@@ -39,7 +39,7 @@
 
 #include "syshead.h"
 
-#if defined(ENABLE_CRYPTO) && defined(ENABLE_SSL)
+#ifdef ENABLE_CRYPTO
 
 #include "error.h"
 #include "common.h"
@@ -51,17 +51,20 @@
 const struct session_id x_session_id_zero;
 
 void
-session_id_random (struct session_id *sid)
+session_id_random(struct session_id *sid)
 {
-  prng_bytes (sid->id, SID_SIZE);
+    prng_bytes(sid->id, SID_SIZE);
 }
 
 const char *
-session_id_print (const struct session_id *sid, struct gc_arena *gc)
+session_id_print(const struct session_id *sid, struct gc_arena *gc)
 {
-  return format_hex (sid->id, SID_SIZE, 0, gc);
+    return format_hex(sid->id, SID_SIZE, 0, gc);
 }
 
-#else
-static void dummy(void) {}
-#endif /* ENABLE_CRYPTO && ENABLE_SSL*/
+#else  /* ifdef ENABLE_CRYPTO */
+static void
+dummy(void)
+{
+}
+#endif /* ENABLE_CRYPTO */
